@@ -1,7 +1,3 @@
-# Allows conflicts. For more information, see library() and
-# conflicts() in [R] base.
-.conflicts.OK <- TRUE 
-
 ## .First.lib <- function(libname, pkgname) {
 .onAttach <- function(libname, pkgname) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
